==> wsclient-8.0.4-1-sources.jar: org/hpccsystems/ws/client/wrappers/gen/wscodesign/Ws_codesignPingResponseWrapper.java <==
package org.hpccsystems.ws.client.wrappers.gen.wscodesign;



/*******************************************************************************
 * HPCC SYSTEMS software Copyright (C) 2019 HPCC Systems.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/

/**
 * Generated Axis2 ADB stub class wrapper
 * Class name: Ws_codesignPingResponseWrapper
 * Wraps class: org.hpccsystems.ws.client.gen.axis2.wscodesign.v1_01.Ws_codesignPingResponse
 * Output package : org.hpccsystems.ws.client.wrappers.gen.wscodesign
 * TimeStamp: 2021-03-26T18:27:31.434Z
 */
public class Ws_codesignPingResponseWrapper
{

	public Ws_codesignPingResponseWrapper() {}

	public org.hpccsystems.ws.client.gen.axis2.wscodesign.v1_01.Ws_codesignPingResponse getRaw()
	{
		org.hpccsystems.ws.client.gen.axis2.wscodesign.v1_01.Ws_codesignPingResponse raw = new org.hpccsystems.ws.client.gen.axis2.wscodesign.v1_01.Ws_codesignPingResponse();
		return raw;
	}


}

==> wsclient-9.4.24-1-sources.jar: org/hpccsystems/ws/client/wrappers/gen/wscodesign/Ws_codesignPingResponseWrapper.java <==
package org.hpccsystems.ws.client.wrappers.gen.wscodesign;

/*******************************************************************************
 * HPCC SYSTEMS software Copyright (C) 2021 HPCC Systems.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *******************************************************************************/

/**
 * Generated Axis2 ADB stub class wrapper
 * Class name: Ws_codesignPingResponseWrapper
 * Wraps class: org.hpccsystems.ws.client.gen.axis2.wscodesign.latest.Ws_codesignPingResponse
 * Output package : org.hpccsystems.ws.client.wrappers.gen.wscodesign
 */
public class Ws_codesignPingResponseWrapper
{

    public Ws_codesignPingResponseWrapper() {}

    public org.hpccsystems.ws.client.gen.axis2.wscodesign.latest.Ws_codesignPingResponse getRaw()
    {
        org.hpccsystems.ws.client.gen.axis2.wscodesign.latest.Ws_codesignPingResponse raw = new org.hpccsystems.ws.client.gen.axis2.wscodesign.latest.Ws_codesignPingResponse();
        return raw;
    }


}
